﻿// Kerbal Engineer Redux
// Author:  CYBUTEK
// License: Attribution-NonCommercial-ShareAlike 3.0 Unported

using System;
using System.Collections.Generic;

namespace Engineer
{
    class ResourceContainer
    {
        Dictionary<int, double> resources = new Dictionary<int, double>();

        public double this[int type]
        {
            get
            {
                if (resources.ContainsKey(type))
                {
                    return resources[type];
                }
                else
                {
                    return 0f;
                }
            }
            set
            {
                if (resources.ContainsKey(type))
                {
                    resources[type] = value;
                }
                else
                {
                    resources.Add(type, value);
                }
            }
        }

        public List<int> Types
        {
            get
            {
                List<int> types = new List<int>();

                foreach (int key in resources.Keys)
                {
                    types.Add(key);
                }

                return types;
            }
        }

        public bool Empty
        {
            get
            {
                foreach (int type in resources.Keys)
                {
                    if (resources[type] > 1f)
                    {
                        return false;
                    }
                }

                return true;
            }
        }

        public void Add(int type, double amount)
        {
            if (resources.ContainsKey(type))
            {
                resources[type] += amount;
            }
            else
            {
                resources.Add(type, amount);
            }
        }

        public void Reset()
        {
            resources = new Dictionary<int, double>();
        }

        public void Debug()
        {
            foreach (int key in resources.Keys)
            {
                UnityEngine.MonoBehaviour.print(" -> " + GetResourceName(key) + " = " + resources[key]);
            }
        }

        public double GetResourceMass(int type)
        {
            return resources[type] * GetResourceDensity(type);
        }

        public static ResourceFlowMode GetResourceFlowMode(int type)
        {
            return PartResourceLibrary.Instance.GetDefinition(type).resourceFlowMode;
        }

        public static ResourceTransferMode GetResourceTransferMode(int type)
        {
            return PartResourceLibrary.Instance.GetDefinition(type).resourceTransferMode;
        }

        public static float GetResourceDensity(int type)
        {
            return PartResourceLibrary.Instance.GetDefinition(type).density;
        }

        public static string GetResourceName(int type)
        {
            return PartResourceLibrary.Instance.GetDefinition(type).name;
        }
    }
}
